## [1.14.1](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.14.0...v1.14.1) (2025-06-30)


### Bug Fixes

* outdated error message instructions ([#196](https://github.com/pathintegral-institute/mcpm.sh/issues/196)) ([49c9be1](https://github.com/pathintegral-institute/mcpm.sh/commit/49c9be170bffca0a7fbf08a8b4f5381c5a95e7a2))

# [1.14.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.13.6...v1.14.0) (2025-06-24)


### Features

* support custom node runtime config ([#186](https://github.com/pathintegral-institute/mcpm.sh/issues/186)) ([3c77974](https://github.com/pathintegral-institute/mcpm.sh/commit/3c7797481c311cfdb16b3add82455a0f07ab838d))

## [1.13.6](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.13.5...v1.13.6) (2025-06-24)


### Bug Fixes

* compatible with goose builtin config ([#185](https://github.com/pathintegral-institute/mcpm.sh/issues/185)) ([8485c1b](https://github.com/pathintegral-institute/mcpm.sh/commit/8485c1b423659eacadebc131a38268d8d6de00de))

## [1.13.5](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.13.4...v1.13.5) (2025-06-16)


### Bug Fixes

* automated fix for [#171](https://github.com/pathintegral-institute/mcpm.sh/issues/171) via Codex ([#173](https://github.com/pathintegral-institute/mcpm.sh/issues/173)) ([88b554b](https://github.com/pathintegral-institute/mcpm.sh/commit/88b554b1d057a470cb44efc0cf26a98941291f35))

## [1.13.4](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.13.3...v1.13.4) (2025-06-07)


### Bug Fixes

* npx path in windows is npx.cmd ([#169](https://github.com/pathintegral-institute/mcpm.sh/issues/169)) ([9dc8746](https://github.com/pathintegral-institute/mcpm.sh/commit/9dc874644a309fb297a310188ce7ad1e753bb67b))

## [1.13.3](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.13.2...v1.13.3) (2025-06-05)


### Bug Fixes

* remove stdout stream handling for share ([#167](https://github.com/pathintegral-institute/mcpm.sh/issues/167)) ([11fddcc](https://github.com/pathintegral-institute/mcpm.sh/commit/11fddcc1ce68e96105cd33f1050f3dd0814ce9e0))

## [1.13.2](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.13.1...v1.13.2) (2025-06-05)


### Bug Fixes

* trigger semantic release for Windows compatibility fix ([16b5e44](https://github.com/pathintegral-institute/mcpm.sh/commit/16b5e44f01c34422c8f8c72528b781cd5f908e44))

## [1.13.1](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.13.0...v1.13.1) (2025-05-29)


### Bug Fixes

*  Fix handle_sse method to match Starlette route endpoint expectations ([#156](https://github.com/pathintegral-institute/mcpm.sh/issues/156)) ([7d13fc1](https://github.com/pathintegral-institute/mcpm.sh/commit/7d13fc12d25d454adf8dd424b2f3a9f39c256815))

# [1.13.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.12.0...v1.13.0) (2025-05-27)


### Features

* router proxy with streamable http server by default ([#155](https://github.com/pathintegral-institute/mcpm.sh/issues/155)) ([b929ced](https://github.com/pathintegral-institute/mcpm.sh/commit/b929ced08b3c7e40736f107379360eabd817bf1d))

# [1.12.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.11.0...v1.12.0) (2025-05-19)


### Features

* support streamable http server connection ([#150](https://github.com/pathintegral-institute/mcpm.sh/issues/150)) ([64fa046](https://github.com/pathintegral-institute/mcpm.sh/commit/64fa046eaa596f3d94e5f13fc132a19f46af2cf9))

# [1.11.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.10.1...v1.11.0) (2025-05-14)


### Features

* add client support for vscode ([#147](https://github.com/pathintegral-institute/mcpm.sh/issues/147)) ([ebbc113](https://github.com/pathintegral-institute/mcpm.sh/commit/ebbc113fcc7be86682ff0873eb94c9320b59f854))

## [1.10.1](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.10.0...v1.10.1) (2025-05-13)


### Bug Fixes

* fix mcp sdk version ([#145](https://github.com/pathintegral-institute/mcpm.sh/issues/145)) ([6e4e32c](https://github.com/pathintegral-institute/mcpm.sh/commit/6e4e32c4383ac84defe191355205012a0ce5cef1))

# [1.10.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.9.0...v1.10.0) (2025-05-12)


### Features

* improve profile management ([#137](https://github.com/pathintegral-institute/mcpm.sh/issues/137)) ([8dcc5ef](https://github.com/pathintegral-institute/mcpm.sh/commit/8dcc5efd0789f06d1d4459fd8c6f4e6e6bcb2aa6))

# [1.9.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.8.0...v1.9.0) (2025-05-05)


### Features

* **share:** add simple share command to reverse proxy a single local mcp server ([#140](https://github.com/pathintegral-institute/mcpm.sh/issues/140)) ([78b1f0b](https://github.com/pathintegral-institute/mcpm.sh/commit/78b1f0b49861608e054e3c6f09c6d5d71174dd68))

# [1.8.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.7.1...v1.8.0) (2025-04-30)


### Features

* **router:** Support custom api key and auth enable/disable in router ([#106](https://github.com/pathintegral-institute/mcpm.sh/issues/106)) ([bf21d42](https://github.com/pathintegral-institute/mcpm.sh/commit/bf21d42cd4d5297edda22b7bf75008e962003b76))

## [1.7.1](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.7.0...v1.7.1) (2025-04-29)


### Bug Fixes

* redirect the stderr of mcp servers to local ([#126](https://github.com/pathintegral-institute/mcpm.sh/issues/126)) ([91694d8](https://github.com/pathintegral-institute/mcpm.sh/commit/91694d8092a5b3e578d8a8ff93f1807fb5ce2326))

# [1.7.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.6.2...v1.7.0) (2025-04-28)


### Features

* support custom add server ([#125](https://github.com/pathintegral-institute/mcpm.sh/issues/125)) ([80bd9c0](https://github.com/pathintegral-institute/mcpm.sh/commit/80bd9c03120a0b2d9d99173754243eff3feb5811))

## [1.6.2](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.6.1...v1.6.2) (2025-04-27)


### Bug Fixes

* explicitly set encoding to utf-8 ([#131](https://github.com/pathintegral-institute/mcpm.sh/issues/131)) ([6a4b4a4](https://github.com/pathintegral-institute/mcpm.sh/commit/6a4b4a4ce693642f2b307ef333b0217272a598a0))

## [1.6.1](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.6.0...v1.6.1) (2025-04-25)


### Bug Fixes

* add port availability check and improve status message for MCPRouter ([#124](https://github.com/pathintegral-institute/mcpm.sh/issues/124)) ([89bf558](https://github.com/pathintegral-institute/mcpm.sh/commit/89bf5583ce19e6542a5bad4ff58a0dd1ad4198bc))

# [1.6.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.5.1...v1.6.0) (2025-04-25)


### Features

* router share with https by default ([#119](https://github.com/pathintegral-institute/mcpm.sh/issues/119)) ([a0e8b67](https://github.com/pathintegral-institute/mcpm.sh/commit/a0e8b673d3895d89e54f2be266ce3193f53d4c6d))

## [1.5.1](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.5.0...v1.5.1) (2025-04-22)


### Bug Fixes

* update installation prompt for manifest generation ([#102](https://github.com/pathintegral-institute/mcpm.sh/issues/102)) ([96d86ee](https://github.com/pathintegral-institute/mcpm.sh/commit/96d86ee8a58fd6703992260230ed8c0f52b045eb))

# [1.5.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.4.4...v1.5.0) (2025-04-22)


### Features

* **client:** Add Trae client support ([#101](https://github.com/pathintegral-institute/mcpm.sh/issues/101)) ([23abe67](https://github.com/pathintegral-institute/mcpm.sh/commit/23abe6705543b65560e7a9e48e664f8490428f1b)), closes [#92](https://github.com/pathintegral-institute/mcpm.sh/issues/92)

## [1.4.4](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.4.3...v1.4.4) (2025-04-21)


### Bug Fixes

* add params field when missing ([#94](https://github.com/pathintegral-institute/mcpm.sh/issues/94)) ([893ebb9](https://github.com/pathintegral-institute/mcpm.sh/commit/893ebb9b2cc6102e9d0128805bad7a105a2a36a1))

## [1.4.3](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.4.2...v1.4.3) (2025-04-21)


### Bug Fixes

* sse url to claude desktop is not converted ([#90](https://github.com/pathintegral-institute/mcpm.sh/issues/90)) ([5f2fc99](https://github.com/pathintegral-institute/mcpm.sh/commit/5f2fc9954bed98c18f3e33859bfa570ff88e1157))

## [1.4.2](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.4.1...v1.4.2) (2025-04-21)


### Bug Fixes

* handle argument value replacement with more patterns ([#75](https://github.com/pathintegral-institute/mcpm.sh/issues/75)) ([f20e469](https://github.com/pathintegral-institute/mcpm.sh/commit/f20e46966fa77dc459e81de08e5c98f05cf3116e))

## [1.4.1](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.4.0...v1.4.1) (2025-04-18)


### Bug Fixes

* update goose cli client name ([#77](https://github.com/pathintegral-institute/mcpm.sh/issues/77)) ([6b17d94](https://github.com/pathintegral-institute/mcpm.sh/commit/6b17d94f97cf0b4d01ad1f11e8b1abb169afc509))

# [1.4.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.3.0...v1.4.0) (2025-04-18)


### Features

* **router:** Improve function naming in router ([654872d](https://github.com/pathintegral-institute/mcpm.sh/commit/654872dec5d7588f115bab67a08ac2779e9383f3))

# [1.3.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.2.0...v1.3.0) (2025-04-18)


### Features

* add share for router ([#74](https://github.com/pathintegral-institute/mcpm.sh/issues/74)) ([e81a852](https://github.com/pathintegral-institute/mcpm.sh/commit/e81a85214f2287acea2b6b667a47a0e7d6f5e462))

# [1.2.0](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.1.2...v1.2.0) (2025-04-17)


### Features

* **command:** Add info command and simplify search output ([#73](https://github.com/pathintegral-institute/mcpm.sh/issues/73)) ([27a4443](https://github.com/pathintegral-institute/mcpm.sh/commit/27a44434c5afe72ee1ceec1b2ef2b6b6a1698f5f))

## [1.1.2](https://github.com/pathintegral-institute/mcpm.sh/compare/v1.1.1...v1.1.2) (2025-04-17)


### Bug Fixes

* add should remove optional argument placeholder ([#62](https://github.com/pathintegral-institute/mcpm.sh/issues/62)) ([9181610](https://github.com/pathintegral-institute/mcpm.sh/commit/9181610fb886944df172f60a5112d20893e25a87))
* update the default user-agent for web-fetch ([#70](https://github.com/pathintegral-institute/mcpm.sh/issues/70)) ([15df122](https://github.com/pathintegral-institute/mcpm.sh/commit/15df12212a7a8ffc9d0ae98d0420cae448fff92a))
